@@ -2,7 +2,7 @@
 *                  Exim monitor                  *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2000 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* This module contains code to initialize things from the
@@ -208,13 +208,13 @@ the size of a partition, then deal with log stripcharts in a separate
 function */
 
 s = getenv("SIZE_STRIPCHART");
-if (s != NULL)
+if (s != NULL && *s != 0)
   {
   stripchart_number++;
   stripchart_varstart++;
   size_stripchart = string_copy(s);
   s = getenv("SIZE_STRIPCHART_NAME");
-  if (s != NULL) size_stripchart_name = string_copy(s);
+  if (s != NULL && *s != 0) size_stripchart_name = string_copy(s);
   }
 
 s = getenv("LOG_STRIPCHARTS");
