@@ -2,7 +2,7 @@
 *               Exim Monitor                     *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -13,6 +13,10 @@
 text widget. It is not used for the log widget, because that
 is dynamically updated and has special scrolling requirements. */
 
+/* Count of characters displayed */
+
+static int text_count = 0;
+
 
 /*************************************************
 *               Empty the widget                 *
@@ -25,17 +29,9 @@ b.firstPos = 0;
 b.ptr = (char *)(&b);
 b.format = FMT8BIT;
 b.length = 0;
-XawTextReplace(w, 0, 999999, &b);
-}
-
-
-/*************************************************
-*           Cause position to be displayed       *
-*************************************************/
-
-void text_position(Widget w, int position)
-{
-XawTextSetInsertionPoint(w, position);
+XawTextReplace(w, 0, text_count, &b);
+text_count = 0;
+XawTextSetInsertionPoint(w, text_count);
 }
 
 
@@ -50,8 +46,9 @@ b.firstPos = 0;
 b.ptr = s;
 b.format = FMT8BIT;
 b.length = (int)strlen(s);
-XawTextReplace(w, 999999, 999999, &b);
-XawTextSetInsertionPoint(w, 99999);
+XawTextReplace(w, text_count, text_count, &b);
+text_count += b.length;
+XawTextSetInsertionPoint(w, text_count);
 }
 
 
