@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -125,7 +125,7 @@ lock_data.l_whence = lock_data.l_start = lock_data.l_len = 0;
 
 sigalrm_seen = FALSE;
 os_non_restarting_signal(SIGALRM, sigalrm_handler);
-alarm(DB_LOCK_TIMEOUT);
+alarm(DB_LOCK_TIMEOUT_EXIM);
 rc = fcntl(dbblock->lockfd, F_SETLKW, &lock_data);
 alarm(0);
 signal(SIGALRM, SIG_IGN);
