@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2000 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -515,10 +515,11 @@ int
 direct_check_fsc(director_instance *dblock, address_item *addr)
 {
 int rc;
+char *error;
 
 debug_print_string(dblock->debug_string);
 
-switch (match_exists(dblock->require_files))
+switch (match_exists(dblock->require_files, &error))
   {
   case FAIL:
   DEBUG(9) debug_printf("%s director skipped: file existence failure\n",
@@ -527,7 +528,7 @@ switch (match_exists(dblock->require_files))
 
   case DEFER:
   addr->message = string_sprintf("file existence defer in %s director: %s",
-    dblock->name, strerror(errno));
+    dblock->name, error);
   return DEFER;
   }
 
@@ -927,7 +928,7 @@ return 0;
 
 
 /*************************************************
-*         Check local part for prefix            *
+*         Check local part for suffix            *
 *************************************************/
 
 /* This functionis handed a local part and a list of possible suffixes;
