@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2000 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 #include "exim.h"
@@ -70,7 +70,16 @@ while (c != 0 && *p != 0)
       log_write(0, LOG_PANIC_DIE,
         "Failed to create directory \"%s\": %s\n", buffer, strerror(errno));
       }
+
+    /* Set the ownership if necessary. */
+
     if (use_chown) chown(buffer, exim_uid, exim_gid);
+
+    /* It appears that any mode bits greater than 0777 are ignored by
+    mkdir(), at least on some operating systems. Therefore, if the mode
+    contains any such bits, do an explicit mode setting. */
+
+    if ((mode & 0777000) != 0) chmod(buffer, mode);
     }
   *p++ = c;
   }
