@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions for interfacing with the DNS. */
@@ -10,12 +10,15 @@
 #include "exim.h"
 
 
-/* Function declaration needed for mutual recursion. */
+/* Function declaration needed for mutual recursion when A6 records
+are supported. */
 
 #if HAVE_IPV6
+#ifdef SUPPORT_A6
 static void dns_complete_a6(dns_address ***, dns_answer *, dns_record *,
   int, uschar *);
 #endif
+#endif
 
 
 
@@ -164,10 +167,8 @@ switch(t)
   {
   case T_A:    return "A";
   case T_MX:   return "MX";
-  #if HAVE_IPV6
   case T_AAAA: return "AAAA";
   case T_A6:   return "A6";
-  #endif
   case T_TXT:  return "TXT";
   case T_PTR:  return "PTR";
   default:     return "?";
@@ -472,7 +473,7 @@ return DNS_FAIL;
 }
 
 
-#if HAVE_IPV6
+#if HAVE_IPV6 && defined(SUPPORT_A6)
 
 /*************************************************
 *        Search DNS block for prefix RRs         *
@@ -624,7 +625,7 @@ will be no addresses at the end. */
 if (dns_lookup(&cdnsa, chainptr, T_A6, NULL) == DNS_SUCCEED)
   (void)dns_find_prefix(&cdnsa, RESET_ANSWERS, chainptr, yptrptr, bits, bitvec);
 }
-#endif
+#endif  /* HAVE_IPV6 && defined(SUPPORT_A6) */
 
 
 
@@ -633,9 +634,11 @@ if (dns_lookup(&cdnsa, chainptr, T_A6, NULL) == DNS_SUCCEED)
 *          Get address(es) from DNS record       *
 *************************************************/
 
-/* The record type is either T_A for an IPv4 address or T_AAAA or T_A6 for an
-IPv6 address. In the latter case, there may be several addresses, generated by
-following chains. A recursive function does all the hard work.
+/* The record type is either T_A for an IPv4 address or T_AAAA (or T_A6 when
+supported) for an IPv6 address. In the A6 case, there may be several addresses,
+generated by following chains. A recursive function does all the hard work.
+A6 records now look like passing into history, so the code is only included
+when explicitly asked for.
 
 Argument:
   dnsa       the DNS answer block
@@ -649,7 +652,7 @@ dns_address_from_rr(dns_answer *dnsa, dns_record *rr)
 {
 dns_address *yield = NULL;
 
-#if HAVE_IPV6
+#if HAVE_IPV6 && defined(SUPPORT_A6)
 dns_address **yieldptr = &yield;
 uschar bitvec[16];
 #else
@@ -665,19 +668,22 @@ if (rr->type == T_A)
   }
 
 #if HAVE_IPV6
-else if (rr->type == T_AAAA)
+
+#ifdef SUPPORT_A6
+else if (rr->type == T_A6)
+  {
+  memset(bitvec, 0, sizeof(bitvec));
+  dns_complete_a6(&yieldptr, dnsa, rr, 0, bitvec);
+  }
+#endif  /* SUPPORT_A6 */
+
+else
   {
   yield = store_get(sizeof(dns_address) + 50);
   inet_ntop(AF_INET6, (uschar *)(rr->data), yield->address, 50);
   yield->next = NULL;
   }
-
-else
-  {
-  memset(bitvec, 0, sizeof(bitvec));
-  dns_complete_a6(&yieldptr, dnsa, rr, 0, bitvec);
-  }
-#endif
+#endif  /* HAVE_IPV6 */
 
 return yield;
 }
