@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -572,10 +572,9 @@ while (last > first)
       lseek(deliver_datafile, start_offset, SEEK_SET);
       len = read(deliver_datafile, body, len);
       if (len >= 0) body[len] = 0;
-      while (*body != 0)
+      while (len > 0)
         {
-        if (*body == '\n') *body = ' ';
-        body++;
+        if (body[--len] == '\n' || body[len] == 0) body[len] = ' ';
         }
       }
     return (*ss == NULL)? "" : *ss;
@@ -1266,7 +1265,7 @@ else if (*s != '}')
   s = read_name(name, sizeof(name), s, "_");
   if (strcmp(name, "fail") == 0)
     {
-    if (!yes)
+    if (!yes && !skipping)
       {
       while (isspace((uschar)*s)) s++;
       if (*s++ != '}') goto FAILED_CURLY;
@@ -1453,7 +1452,7 @@ while (*s != 0)
   if (*s == '\\')
     {
     char ch[1];
-    if (*s == 0)
+    if (s[1] == 0)
       {
       expand_string_message = "\\ at end of string";
       goto EXPAND_FAILED;
