@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -124,7 +124,7 @@ extern int   host_self_action(address_item *, host_item *, int, BOOL, char *);
 extern void  log_close_all(void);
 extern void  log_write(int, int, char *format, ...);
 
-extern BOOL  match_address_list(char *, int, char **, int, int *, BOOL);
+extern BOOL  match_address_list(char *, int, BOOL, char **, int, int *, BOOL);
 extern int   match_exists(char *, char **);
 extern BOOL  match_isinlist(char *, char **, BOOL, BOOL, char **);
 extern BOOL  match_check_string(char *, char *, int, BOOL, BOOL, char **);
@@ -224,7 +224,7 @@ extern BOOL  spool_move_message(char *, char *, char *, char *);
 extern BOOL  spool_open_datafile(char *);
 extern int   spool_open_temp(char *);
 extern int   spool_read_header(char *, BOOL, BOOL);
-extern int   spool_write_header(char *, BOOL);
+extern int   spool_write_header(char *, int, char **);
 extern BOOL  store_extend_3(void *, int, int, char *, int);
 extern void  store_free_3(void *, char *, int);
 extern void *store_get_3(int, char *, int);
