@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* All the global variables are defined together in this one header, so that
@@ -291,6 +291,7 @@ extern BOOL   log_received_sender;    /* Before rewriting */
 extern BOOL   log_received_recipients; /* As it says (before rewriting) */
 extern BOOL   log_refused_recipients; /* Sic */
 extern BOOL   log_rewrites;           /* Sic */
+extern BOOL   log_sender_on_delivery; /* Sic */
 extern BOOL   log_smtp_confirmation;  /* Log response after "." */
 extern BOOL   log_smtp_connections;   /* Verbose connection logging */
 extern BOOL   log_smtp_syntax_errors; /* As it says (for incoming smtp) */
@@ -468,7 +469,7 @@ extern char  *sender_address;         /* Envelope sender */
 extern BOOL   sender_address_forced;  /* Set by -f */
 extern char  *sender_address_relay;   /* Only non-nearby relay from these addresses */
 extern char  *sender_address_relay_hosts; /* ... if from these hosts */
-extern BOOL   sender_address_rewritten; /* True if rewritten by verify */
+extern char *sender_address_unrewritten; /* Set of verify rewrites */
 extern char  *sender_fullhost;        /* Sender host name + address */
 extern char  *sender_helo_name;       /* Host name from HELO/EHLO */
 extern char  *sender_host_address;    /* IP address of sender, as chars */
@@ -530,6 +531,7 @@ extern char  *stderr_filename;        /* File for use with -df */
 extern int    store_pool;             /* Current pool number */
 extern BOOL   strip_excess_angle_brackets; /* Surrounding route-addrs */
 extern BOOL   strip_trailing_dot;     /* Remove dots at ends of domains */
+extern BOOL   syslog_timestamp;       /* TRUE for timestamps on syslogs */
 
 extern int    timeout_frozen_after;   /* Max time to keep frozen messages */
 extern BOOL   timestamps_utc;         /* Use UTC for all times */
