@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions for finding hosts, either by gethostbyname, gethostbyaddr, or via
@@ -1464,7 +1464,7 @@ if (rc != DNS_SUCCEED)
     if (rc == HOST_FOUND)
       {
       while (last->next != next) last = last->next;
-      rc = host_scan_for_local_hosts(host, last, NULL);
+      rc = host_scan_for_local_hosts(host, last, removed);
       }
     else
       if (rc == HOST_IGNORED) rc = HOST_FIND_FAILED;  /* No special action */
