@@ -121,6 +121,18 @@ Changed this test from __hpux to hpux on 2-Feb-99 (PH). */
     if (id->buf[pos] != '\n' && id->buf[pos] != '\r')
 	return 0;		/* Not properly terminated string */
 
+    /******/
+    /* Patch from Tim Waugh: swallow the LF that should follow the CR.
+    This means that it reads all the data, instead of leaving one byte
+    pending. */
+
+    if (id->buf[pos] == '\r')
+      {
+      char discard;
+      read (id->fd, &discard, 1);
+      }
+    /******/
+
     id->buf[pos++] = '\0';
 
     /*
