@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 #include "../exim.h"
@@ -23,7 +23,9 @@ static char *type_names[] = {
   "a",
 #if HAVE_IPV6
   "aaaa",
+  #ifdef SUPPORT_A6
   "a6",
+  #endif
 #endif
   "cname",
   "mx",
@@ -35,7 +37,9 @@ static int type_values[] = {
   T_A,
 #if HAVE_IPV6
   T_AAAA,
+  #ifdef SUPPORT_A6
   T_A6,
+  #endif
 #endif
   T_CNAME,
   T_MX,
@@ -212,9 +216,16 @@ for (rr = dns_next_rr(&dnsa, &dnss, RESET_ANSWERS);
   /* There may be several addresses from an A6 record. Put newlines between
   them, just as for between several records. */
 
-  if (type == T_A || type == T_AAAA || type == T_A6)
+  if (type == T_A ||
+      #ifdef SUPPORT_A6
+      type == T_A6 ||
+      #endif
+      type == T_AAAA)
     {
     dns_address *da;
+
+    /* This loop runs only once for A and AAAA records */
+
     for (da = dns_address_from_rr(&dnsa, rr); da != NULL; da = da->next)
       {
       len = (int)strlen(CS da->address);
