@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -78,7 +78,7 @@ unsigned. */
   ((uschar)(c) > 32 && (uschar)(c) != 127)
 
 #define mac_isprint(c) \
-  (((uschar)(c) >= 32 && (uschar)(c) <= 126) || \
+  (((uschar)(c) >= 32 && (uschar)(c) <= 126) || c == '\t' || \
   ((uschar)(c) > 127 && print_topbitchars))
 
 
@@ -110,20 +110,6 @@ don't make both fd's two-way. */
 #define POOL_MAIN 0
 #define POOL_TEMP 1
 
-/* The EDQUOT error code isn't universally available, though it is widespread.
-There is a particular shambles in SunOS5, where it did not exist originally,
-but got installed with a particular patch for Solaris 2.4. There is a
-configuration variable for specifying what the system's "over quota" error is,
-but if it is not set, default to EDQUOT if it exists, otherwise ENOSPC. */
-
-#ifndef ERRNO_QUOTA
-#ifdef  EDQUOT
-#define ERRNO_QUOTA EDQUOT
-#else
-#define ERRNO_QUOTA ENOSPC
-#endif
-#endif
-
 /* Simplify taking the larger of two values */
 
 #define mac_max(a, b) ((a) > (b) ? (a) : (b))
@@ -176,9 +162,11 @@ as long as the maximum path length. */
 #define BIG_BUFFER_SIZE 1024
 #endif
 
-/* A limit to the length of a sender address */
+/* A limit to the length of an address. RFC 2821 limits the local part to 64
+and the domain to 255, so this should be adequate, taking into account quotings
+etc. */
 
-#define SENDER_ADDRESS_MAXLENGTH 512
+#define ADDRESS_MAXLENGTH 512
 
 /* The length of message identification strings. This is the id used internally
 by exim. The external version for use in Received: strings has a leading 'E'
@@ -557,4 +545,8 @@ enum {
 #define dsn_ret_full            1
 #define dsn_ret_hdrs            2
 
+/* Situations for spool_write_header() */
+
+enum { SW_RECEIVING, SW_DELIVERING, SW_MODIFYING };
+
 /* End of macros.h */
