@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions that operate on the input queue. */
@@ -407,10 +407,12 @@ for (i  = (queue_run_in_order? -1 : 0);
 
     if (deliver_selectstring != NULL || deliver_selectstring_sender != NULL)
       {
+      BOOL old_dont_deliver = dont_deliver;
       BOOL wanted = TRUE;
       void *reset_point2 = store_get(0);
 
       if (spool_read_header(f->text, FALSE, TRUE) != spool_read_OK) continue;
+      dont_deliver = old_dont_deliver;
 
       if (deliver_freeze && !deliver_force_thaw)
         {
@@ -698,8 +700,7 @@ else
 if (option >= 8) option -= 8;
 
 /* Now scan the chain and print information, resetting store used
-each time. If queue_list_requires_admin is TRUE and the caller is not
-an admin user, list only those messages that were submitted by the caller. */
+each time. */
 
 reset_point = store_get(0);
 
@@ -716,9 +717,6 @@ for (; f != NULL; f = f->next)
   if (rc == spool_read_notopen && errno == ENOENT && count <= 0) continue;
   save_errno = errno;
 
-  if (queue_list_requires_admin && !admin_user &&
-     (rc != spool_read_OK || real_uid != originator_uid)) continue;
-
   env_read = (rc == spool_read_OK || rc == spool_read_hdrerror);
 
   if (env_read)
@@ -836,9 +834,11 @@ queue_action(char *id, int action, char **argv, int argc, int recipients_arg)
 {
 int i, j;
 BOOL yield = TRUE;
+BOOL removed = FALSE;
 struct passwd *pw;
 char *doing = NULL;
 char *username;
+char *errmsg;
 char spoolname[256];
 
 /* Set the global message_id variable, used when re-writing spool files. This
@@ -984,7 +984,7 @@ switch(action)
     deliver_freeze = TRUE;
     deliver_manual_thaw = FALSE;
     deliver_frozen_at = time(NULL);
-    if (spool_write_header(id, FALSE) >= 0)
+    if (spool_write_header(id, SW_MODIFYING, &errmsg) >= 0)
       {
       printf("is now frozen\n");
       log_write(0, LOG_MAIN, "frozen by %s", username);
@@ -992,8 +992,7 @@ switch(action)
     else
       {
       yield = FALSE;
-      printf("could not be frozen: failed to rewrite spool header file: %s\n",
-        strerror(errno));
+      printf("could not be frozen: %s\n", errmsg);
       }
     }
   break;
@@ -1009,7 +1008,7 @@ switch(action)
     {
     deliver_freeze = FALSE;
     deliver_manual_thaw = TRUE;
-    if (spool_write_header(id, FALSE) >= 0)
+    if (spool_write_header(id, SW_MODIFYING, &errmsg) >= 0)
       {
       printf("is no longer frozen\n");
       log_write(0, LOG_MAIN, "unfrozen by %s", username);
@@ -1017,8 +1016,7 @@ switch(action)
     else
       {
       yield = FALSE;
-      printf("could not be unfrozen: failed to rewrite spool header file: %s\n",
-        strerror(errno));
+      printf("could not be unfrozen: %s\n", errmsg);
       }
     }
   break;
@@ -1044,6 +1042,7 @@ switch(action)
           strerror(errno));
         }
       }
+    else removed = TRUE;
 
     for (i = 0; i < 3; i++)
       {
@@ -1058,6 +1057,7 @@ switch(action)
             strerror(errno));
           }
         }
+      else removed = TRUE;
       }
     }
 
@@ -1066,7 +1066,7 @@ switch(action)
 
   if (deliver_datafile >= 0) printf("has been removed\n");
     else printf("has been removed or did not exist\n");
-  log_write(0, LOG_MAIN, "removed by %s", username);
+  if (removed) log_write(0, LOG_MAIN, "removed by %s", username);
   break;
 
 
@@ -1075,7 +1075,7 @@ switch(action)
     {
     tree_add_nonrecipient(recipients_list[i].address, FALSE);
     }
-  if (spool_write_header(id, FALSE) >= 0)
+  if (spool_write_header(id, SW_MODIFYING, &errmsg) >= 0)
     {
     printf("has been modified\n");
     for (i = 0; i < recipients_count; i++)
@@ -1085,8 +1085,7 @@ switch(action)
   else
     {
     yield = FALSE;
-    printf("- failed to rewrite spool header file "
-      "while marking all recipients delivered_ %s\n", strerror(errno));
+    printf("- could not mark all delivered: %s\n", errmsg);
     }
   break;
 
@@ -1174,13 +1173,12 @@ switch(action)
 
     if (yield)
       {
-      if (spool_write_header(id, FALSE) >= 0)
+      if (spool_write_header(id, SW_MODIFYING, &errmsg) >= 0)
         printf("has been modified\n");
       else
         {
         yield = FALSE;
-        printf("- failed to rewrite spool header file while %s: %s\n", doing,
-          strerror(errno));
+        printf("- while %s: %s\n", doing, errmsg);
         }
       }
     }
