@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions concerned with rewriting headers */
@@ -135,8 +135,8 @@ for (rule = rewrite_rules;
     /* Use the general function for matching an address against a list (here
     just one item, so set the separator to 0). */
 
-    if (!match_address_list(subject,domain-subject,&(rule->key),0,&sep,FALSE))
-      continue;
+    if (!match_address_list(subject, domain-subject, FALSE, &(rule->key), 0,
+      &sep, FALSE)) continue;
 
     /* The source address matches, and numerical variables have been
     set up. If the replacement string consists of precisely "*" then no
