@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -215,8 +215,9 @@ while (*s != 0 && isspace((uschar)*s)) s++;
 
 if (*s == '\"' || *s == '\'')
   {
+  int quote = *s;
   *hostlist = ++s;
-  while (*s != 0 && *s != '\"' && *s != '\'') s++;
+  while (*s != 0 && *s != quote) s++;
   }
 else
   {
