@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions for reading spool files. */
@@ -453,12 +453,28 @@ for (n = 0; n < recipients_count; n++)
   left here just in case. Nothing is documented.
 
   Jan, 2002: Added code to make it read the Exim 4 version of this, which
-  is just a single number.
-  */
+  is just a single number. At least, it was at first. Later it was revised
+  to a more flexible format. Further code added: April 2002. */
 
   p = big_buffer + nn - 2;
   while (isdigit((uschar)*p) || *p == ',') p--;
-  if (*p == ' ')
+
+  /* New Exim 4 style */
+
+  if (*p == '#')
+    {
+    int len;
+    p--;
+    while (isdigit((uschar)*p) || *p == ',') p--;
+    sscanf(p+1, "%d,%d", &len, &pno);
+    flags = rf_onetime;
+    p -= len + 1;
+    *p = 0;
+    }
+
+  /* Old Exim 4 style and Exim 3 style */
+
+  else if (*p == ' ')
     {
     int orc;
     *p++ = 0;
