@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions for writing spool files, and moving them about. */
@@ -16,29 +16,42 @@
 *       Deal with header writing errors          *
 *************************************************/
 
-/* This function is called after errors in writing the spool. If pof is set,
-log the error using the text provided, and panic-die. Otherwise return -1 with
-errno preserved and don't log anything - it is assumed the caller will deal
-with logging in that case. This function makes the code of spool_write_header()
-a bit neater.
+/* This function is called immediately after errors in writing the spool, with
+errno still set. It creates and error message, depending on the circumstances.
+If errmsg is NULL, it logs the message and panic-dies. Otherwise errmsg is set
+to point to the message, and -1 is returned. This function makes the code of
+spool_write_header() a bit neater.
 
 Arguments:
-   pof        TRUE for panic on failure
+   where      SW_RECEIVING, SW_DELIVERING, or SW_MODIFYING
+   errmsg     where to put the message; NULL => panic-die
    s          text to add to log string
    temp_name  name of temp file to unlink
    f          FILE to close, if not NULL
 
-Returns:      -1 if pof is TRUE; otherwise doesn't return
+Returns:      -1 if errmsg is not NULL; otherwise doesn't return
 */
 
 static int
-spool_write_error(BOOL pof, char *s, char *temp_name, FILE *f)
+spool_write_error(int where, char **errmsg, char *s, char *temp_name, FILE *f)
 {
+char *msg = (where == SW_RECEIVING)?
+  string_sprintf("spool file %s error while receiving from %s: %s", s,
+    (sender_fullhost != NULL)? sender_fullhost : sender_ident,
+    strerror(errno))
+  :
+  string_sprintf("spool file %s error while %s: %s", s,
+    (where == SW_DELIVERING)? "delivering" : "modifying",
+    strerror(errno));
+
 if (temp_name != NULL) unlink(temp_name);
 if (f != NULL) fclose(f);
-if(pof)
-  log_write(0, LOG_MAIN|LOG_PANIC_DIE, "unable to update spool header "
-     "file for %s: %s error %s", message_id, s, strerror(errno));
+
+if (errmsg == NULL)
+  log_write(0, LOG_MAIN|LOG_PANIC_DIE, "%s", msg);
+else
+  *errmsg = msg;
+
 return -1;
 }
 
@@ -102,14 +115,15 @@ message.
 
 Argument:
   id      the message id
-  pof     if TRUE, log and panic-die on write failures
+  where   SW_RECEIVING, SW_DELIVERING, or SW_MODIFYING
+  errmsg  where to put an error message; if NULL, panic-die on error
 
 Returns:  the size of the header texts on success;
-          negative (with errno set) on writing failure, unless pof is TRUE
+          negative on writing failure, unless errmsg == NULL
 */
 
 int
-spool_write_header(char *id, BOOL pof)
+spool_write_header(char *id, int where, char **errmsg)
 {
 int fd;
 int i;
@@ -123,8 +137,7 @@ char temp_name[256];
 sprintf(temp_name, "%s/input/%s/hdr.%d", spool_directory, message_subdir,
   (int)getpid());
 fd = spool_open_temp(temp_name);
-if (fd < 0) return spool_write_error(pof, "open", NULL, NULL);
-
+if (fd < 0) return spool_write_error(where, errmsg, "open", NULL, NULL);
 f = fdopen(fd, "w");
 DEBUG(9) debug_printf("Writing spool header file\n");
 
@@ -258,18 +271,20 @@ for (h = header_list; h != NULL; h = h->next)
 /* Flush and check for any errors while writing */
 
 if (fflush(f) != 0 || ferror(f))
-  return spool_write_error(pof, "write", temp_name, f);
+  return spool_write_error(where, errmsg, "write", temp_name, f);
 
 /* Force the file's contents to be written to disc. Note that fflush()
 just pushes it out of C, and fclose() doesn't guarantee to do the write
 either. That's just the way Unix works... */
 
-if (fsync(fileno(f)) < 0) return spool_write_error(pof, "sync", temp_name, f);
+if (fsync(fileno(f)) < 0)
+  return spool_write_error(where, errmsg, "sync", temp_name, f);
 
 /* Get the size of the file, and close it. */
 
 fstat(fd, &statbuf);
-if (fclose(f) != 0) return spool_write_error(pof, "close", temp_name, NULL);
+if (fclose(f) != 0)
+  return spool_write_error(where, errmsg, "close", temp_name, NULL);
 
 /* Rename the file to its correct name, thereby replacing any previous
 incarnation. */
@@ -277,7 +292,7 @@ incarnation. */
 sprintf(name, "%s/input/%s/%s-H", spool_directory, message_subdir, id);
 
 if (rename(temp_name, name) < 0)
-  return spool_write_error(pof, "rename", temp_name, NULL);
+  return spool_write_error(where, errmsg, "rename", temp_name, NULL);
 
 /* Return the number of characters in the headers, which is the file size, less
 the prelimary stuff, less the additional count fields on the headers. */
