@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* This module provides TLS (aka SSL) support for Exim. The code is based on a
@@ -579,7 +579,7 @@ if (expcerts != NULL)
   else
     {
     char *file, *dir;
-    if ((statbuf.st_mode & S_IFDIR) != 0)
+    if ((statbuf.st_mode & S_IFMT) == S_IFDIR)
       { file = NULL; dir = expcerts; }
     else
       { file = expcerts; dir = NULL; }
