@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 #include "../exim.h"
@@ -1812,6 +1812,13 @@ if (continuing)
     continue_host_address = host_ntoa(-1, (struct sockaddr *)(&continue_sock),
       NULL, NULL);
 
+  if (continue_host_address == NULL)
+    {
+    log_write(0, LOG_MAIN|LOG_PANIC, "failed to get IP address of stdin "
+      "when socket passed from previous delivery: %s", strerror(errno));
+    continue_host_address = "";
+    }
+
   DEBUG(9) debug_printf("already connected to %s [%s]\n", continue_hostname,
     continue_host_address);
   }
