@@ -2,7 +2,7 @@
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2001 */
+/* Copyright (c) University of Cambridge 1995 - 2002 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Functions concerned with verifying things. */
@@ -823,7 +823,7 @@ open_db *dbm_file;
 dbdata_reject *reject;
 int rc, rejectlen, yield;
 time_t now;
-char buffer[SENDER_ADDRESS_MAXLENGTH + 256];
+char buffer[ADDRESS_MAXLENGTH + 256];
 
 /* If the sender address is empty, it's an error message with, in effect,
 no sender, and we can't check anything. */
@@ -856,8 +856,8 @@ if (rc == OK)
   if (newaddr != NULL)
     {
     DEBUG(2) debug_printf("%s verified ok as %s\n", sender_address, newaddr);
+    sender_address_unrewritten = sender_address;
     sender_address = newaddr;
-    sender_address_rewritten = TRUE;  /* Prevent accept from doing it again */
     }
   else
     {
@@ -1236,9 +1236,11 @@ if (rfc1413_query_timeout > 0 && verify_check_host(&rfc1413_hosts, FALSE))
     strncpy(ident_buffer, ident_ptr, sizeof(ident_buffer));
     ident_buffer[sizeof(ident_buffer) - 1] = 0;
     sender_ident = string_printing(ident_buffer);
+    DEBUG(9) debug_printf("sender_ident = %s\n", sender_ident);
     /* NB: free() not store_free() as it wasn't got by store_malloc() */
     free(ident_ptr);
     }
+  else DEBUG(9) debug_printf("ident callback failed\n");
   }
 }
 
